==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgtranscript.h <==
/***************************************************************************
                          dlgtranscript.h  -  Session Transcript dialog
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : P nov 1 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGTRANSCRIPT_H
#define DLGTRANSCRIPT_H

#include <kdialogbase.h>

class QCheckBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QPushButton;
class KLineEdit;

/**
Configures session transcript.
  *@author Tomas Mecir
  */

class dlgTranscript : public KDialogBase  {
   Q_OBJECT
public: 
  dlgTranscript (QWidget *parent=0, const char *name=0);
  ~dlgTranscript ();

  QString getFName ();
  QString getAFName ();
  void setFName (const QString &filename);
  void setAFName (const QString &filename);
  bool isEnabled ();
  void setEnabled (bool val);
  bool isOverwrite ();
  void setOverwrite (bool val);
  bool includeDump ();
  void setIncludeDump (bool val);
  void setAdvTranscript (bool val);
  bool advTranscript ();
  void setRotateDaily (bool val);
  bool rotateDaily ();
  void setIncludeTimestamp (bool val);
  bool includeTimestamp ();
  void setTranscriptType (char type);
  char transcriptType ();
  void setAdvTranscriptType (char type);
  char advTranscriptType ();
protected slots:
  void updateDialog (bool how);
  void updateAdvDialog (bool how);
  void browseFiles ();
protected:
  QCheckBox *enabletranscript;
  QCheckBox *enableadvtranscript;
  QCheckBox *rotatedaily;
  QCheckBox *includetimestamp;
  QCheckBox *overwrite, *allowansi;
  QCheckBox *includedump;
  KLineEdit *fname, *afname;

  QGroupBox *transbox;
  QGroupBox *advtrans;
  QLabel *lblname;
  QPushButton *filebutton;
  
  QComboBox *ttype, *advttype;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgtranscript.h <==
/***************************************************************************
                          dlgtranscript.h  -  Session Transcript dialog
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : P nov 1 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGTRANSCRIPT_H
#define DLGTRANSCRIPT_H

#include <kdialogbase.h>

class QCheckBox;
class QComboBox;
class QGroupBox;
class QLabel;
class QPushButton;
class KLineEdit;

/**
Configures session transcript.
  *@author Tomas Mecir
  */

class dlgTranscript : public KDialogBase  {
   Q_OBJECT
public: 
  dlgTranscript (QWidget *parent=0, const char *name=0);
  ~dlgTranscript ();

  QString getFName ();
  QString getAFName ();
  void setFName (const QString &filename);
  void setAFName (const QString &filename);
  bool isEnabled ();
  void setEnabled (bool val);
  bool isOverwrite ();
  void setOverwrite (bool val);
  bool includeDump ();
  void setIncludeDump (bool val);
  void setAdvTranscript (bool val);
  bool advTranscript ();
  void setRotateDaily (bool val);
  bool rotateDaily ();
  void setIncludeTimestamp (bool val);
  bool includeTimestamp ();
  void setTranscriptType (char type);
  char transcriptType ();
  void setAdvTranscriptType (char type);
  char advTranscriptType ();
protected slots:
  void updateDialog (bool how);
  void updateAdvDialog (bool how);
  void browseFiles ();
protected:
  QCheckBox *enabletranscript;
  QCheckBox *enableadvtranscript;
  QCheckBox *rotatedaily;
  QCheckBox *includetimestamp;
  QCheckBox *overwrite, *allowansi;
  QCheckBox *includedump;
  KLineEdit *fname, *afname;

  QGroupBox *transbox;
  QGroupBox *advtrans;
  QLabel *lblname;
  QPushButton *filebutton;
  
  QComboBox *ttype, *advttype;
};

#endif
